vs.2.0

//*********************************************************
// www.UltimateGameProgramming.com
// Vertex Shader used with the Dot3 Bump Mapping Demo
// Created by the Programming Ace.
//
// Input Registers used:
//   v0 - Input vertex position.
//   v3 - Input vertex normal.
//   v7 - Input texture coordinate.
//   v8 - Input sTangent vector.
//   v9 - Input binormal vector.
//
// Output Registers used:
//   oPos - Output pos.
//   oD0  - Output color.
//   oT0  - Output tex coord.
//
// Constant Registers used:
//   c0 - Stores the model view projection matrix (c0 - c3).
//   c4 - Stores the world matrix (c4 - c7).
//   c8 - Stores the light vector.
//   c9 - Stores the half angle.
//
// Temporary Registers used:
//   r0 - Temporary register to hold out pos.
//   r1 - Temporary register to hold new sTangent.
//   r2 - Temporary register to hold new normal.
//   r3 - Temporary register to hold new binormal.
//   r4 - Temporary register to hold texture space light vector.
//
// Note:
//   We are using the color output to hold the ligh vector.
//   This way the pixel shader can get it striaght from the
//   color input register (v0 in pixel shader).
//
//*********************************************************


dcl_position v0			      // Vertex postion (x, y, z).
dcl_normal0 v3                // Vertex normal.
dcl_texcoord v7			      // Texture coordinate for this vertex.
dcl_tangent v8                // sTangent for this vertex.
dcl_binormal v9               // tTangent or binormal of this vertex.

def c9, 0.5f,0.5f,0.5f,0.5f   // Define for the half angle.

m4x4 r0, v0, c0			      // Convert to clip space.

m4x4 r1, v8, c4               // Create the sTangent in the right space.
m4x4 r2, v3, c4               // Create the normal in the right space.
m4x4 r3, v9, c4               // Create the binormal in the right space.

dp3 r4.x, r1, -c8             // Convert light x vector to texture space.
dp3 r4.y, r3, -c8             // Convert light y vector to texture space.
dp3 r4.z, r2, -c8             // Convert light z vector to texture space.

mov oPos, r0                  // Set final out pos.
mov oT0, v7                   // Set final texture coord.
mad oD0.xyz, r4.xyz, c9, c9   // Multiply by 0.5 then add 0.5 to put in range of 0-1.